scipy.io.netcdf.netcdf_variable
===============================

.. currentmodule:: scipy.io.netcdf

.. autoclass:: netcdf_variable

   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         netcdf_variable.assignValue
         netcdf_variable.getValue
         netcdf_variable.itemsize
         netcdf_variable.typecode



   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         netcdf_variable.isrec
         netcdf_variable.shape

